# endersgame ![tests](https://github.com/microprediction/endersgame/actions/workflows/tests.yml/badge.svg)


- See the [Attackers](https://github.com/microprediction/endersgame/tree/main/endersgame/attackers) README
- It is strongly recommended that you read the [FAQ](https://github.com/microprediction/endersgame/blob/main/endersgame/attackers/FAQ.md). 


### Install 
Coming to PyPI soon but for now...

     pip install git+https://github.com/microprediction/endersgame.git

